@@ -1,5 +1,8 @@
 # -*- coding: utf-8 -*-
 """
+Author: Peter Mawhorter
+Contributors: Lyn Turbak, Ohana Turbak
+
 A simple (and cheesy-sounding) sound-synthesis library for playing with
 some basic sounds. This library does not by default play any sounds using
 your system's speakers. It just generates lists of numbers between 0 and
@@ -25,7 +28,7 @@ select from a few different scale types including major, minor, and
 pentatonic scales.
 """
 
-__version__ = "2.0.0"
+__version__ = "2.0.1"
 
 import math, random, struct, wave
 
@@ -308,6 +311,7 @@ def setScaleType(scaleType):
     a pair of such lists may be provided specifying first the ascending
     and then the descending note sequences.
     """
+    global CURRENT_KEY
     if not isinstance(scaleType, (list, tuple, str)):
         raise TypeError(
             (
@@ -327,6 +331,8 @@ def setScaleType(scaleType):
             )
         )
 
+    CURRENT_KEY = (CURRENT_KEY[0], scaleType)
+
 
 #-----------------#
 # Tone management #
@@ -1221,7 +1227,7 @@ def currentDrum():
     return CURRENT_DRUM
 
 
-CURRENT_PITCH = A3 # noqa F821
+CURRENT_PITCH = C4 # noqa F821
 """
 The pitch to use when `addNote` is called. Change using `setPitch`, or
 `climbUp` and related functions.
